@@ -4,8 +4,8 @@ from django.conf import settings
 
 
 class AbstractCreateUpdateTime(models.Model):
-    created_time = models.DateTimeField(auto_now_add=True, related_name="%(app_label)s_%(class)s_created_time")
-    updated_time = models.DateTimeField(auto_now=True, related_name="%(app_label)s_%(class)s_updated_time")
+    created_time = models.DateTimeField(auto_now_add=True)
+    updated_time = models.DateTimeField(auto_now=True)
 
     class Meta:
         abstract = True
@@ -13,16 +13,18 @@ class AbstractCreateUpdateTime(models.Model):
 
 class AbstractCreateUpdateUser(AbstractCreateUpdateTime):
     created_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL,
-                                   related_name="%(app_label)s_%(class)s_created_by")
+                                   related_name="%(app_label)s_%(class)s_created_by",
+                                   related_query_name="%(app_label)s_%(class)ss",)
     updated_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL,
-                                   related_name="%(app_label)s_%(class)s_updated_by")
+                                   related_name="%(app_label)s_%(class)s_updated_by",
+                                   related_query_name="%(app_label)s_%(class)ss",)
 
     class Meta:
         abstract = True
 
 
 class AbstractDeleteTime(AbstractCreateUpdateTime):
-    deleted_time = models.DateTimeField(blank=True, null=True, related_name="%(app_label)s_%(class)s_deleted_time")
+    deleted_time = models.DateTimeField(blank=True, null=True)
     is_deleted = models.BooleanField(default=False)
 
     def __init__(self, *args, **kwargs):
@@ -45,7 +47,8 @@ class AbstractDeleteTime(AbstractCreateUpdateTime):
 
 class AbstractDeleteUser(AbstractDeleteTime, AbstractCreateUpdateTime):
     deleted_by = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, on_delete=models.SET_NULL,
-                                   related_name="%(app_label)s_%(class)s_deleted_by")
+                                   related_name="%(app_label)s_%(class)s_deleted_by",
+                                   related_query_name="%(app_label)s_%(class)ss",)
 
     class Meta:
         abstract = True
